@@ -1,5 +1,5 @@
 from sp_api.base import Client, sp_endpoint
-from sp_api.base.helpers import create_md5, fill_query_params
+from sp_api.base.helpers import create_md5
 import urllib.parse
 
 
@@ -12,4 +12,4 @@ class Upload(Client):
             'contentType': kwargs.pop('contentType', content_type),
             'marketplaceIds': self.marketplace_id
         })
-        return self._request(fill_query_params(kwargs.pop('path'), resource), params=kwargs)
+        return self._request(kwargs.pop('path').format(resource), params=kwargs)
